@@ -152,7 +152,7 @@ pub mod macros {
     macro_rules! read_csv {
         ($path:expr) => {{
             let data = std::fs::read($path).unwrap();
-            let data_vec = split_to_vec!(&String::from_utf8_lossy(&data), "\r\n");
+            let data_vec = split_to_vec!(&String::from_utf8_lossy(&data), "\n");
             let data_each_vec = data_vec
                 .iter()
                 .map(|s| split_to_vec!(s, ","))
@@ -618,19 +618,10 @@ pub mod macros {
                     re.push(*item as $type);
                 }
             }
-
             re
         };};
     }
-
-    pub fn run() {
-        let v1: Vec<f64> = vec_element_parse!(vec!["15.", "2.9"], f64);
-        let v2: Vec<i128> = vec_element_parse!(vec!["15", "2"], i128);
-        let v3: Vec<f32> = vec_element_parse!(vec![".15", ".2"], f32);
-        assert_eq!(vec![15.0, 2.9], v1);
-        assert_eq!(vec![15, 2], v2);
-        assert_eq!(vec![0.15, 0.2], v3);
-    }
+    pub fn run() {}
 }
 
 #[cfg(test)]
